@@ -8,7 +8,7 @@ no warnings 'recursion';  # trees can be quite deep
 
 package XML::Compile::Translate;
 use vars '$VERSION';
-$VERSION = '1.45';
+$VERSION = '1.46';
 
 
 # Errors are either in _class 'usage': called with request
@@ -78,7 +78,7 @@ sub compile($@)
 {   my ($self, $item, %args) = @_;
     @$self{keys %args} = values %args;  # dirty
 
-    my $path   = $self->prefixed($item) || $item;
+    my $path   = $self->prefixed($item, 1) || $item;
     ref $item
         and panic "expecting an item as point to start at $path";
 
@@ -806,7 +806,7 @@ sub particleElement($)
                    , name => $refname, where => $where, _class => 'schema';
 
         return $self->element($tree->descend($def->{node}
-          , $self->prefixed($refname)));
+          , $self->prefixed($refname, 1)));
     }
 
     my $name = $node->getAttribute('name');
@@ -855,7 +855,7 @@ sub particleGroup($)
         or error __x"cannot find group `{name}' at {where}"
              , name => $typename, where => $where, _class => 'schema';
 
-    my $group = $tree->descend($dest->{node}, $self->prefixed($typename));
+    my $group = $tree->descend($dest->{node}, $self->prefixed($typename, 1));
     return () if $group->nrChildren==0;
 
     $group->nrChildren==1
@@ -984,13 +984,13 @@ sub keyRewrite($;$)
     $key;
 }
 
-sub prefixed($)
-{   my ($self, $qname) = @_;
+sub prefixed($;$)
+{   my ($self, $qname, $hide) = @_;
     my ($ns, $local) = unpack_type $qname;
     defined $ns or return $qname;
 
     my $pn = $self->{prefixes}{$ns} or return;
-    $pn->{used}++;
+    $pn->{used}++ unless $hide ;
     length $pn->{prefix} ? "$pn->{prefix}:$local" : $local;
 }
 
